@@ -1,5 +1,8 @@
+"""Plots that are frequently useful to us"""
+
 from oplot.multiplots import ax_func_to_plot
 from oplot.ui_scores_mapping import make_ui_score_mapping
 from oplot.outlier_scores import plot_scores_and_zones
 from oplot.plot_data_set import scatter_and_color_according_to_y, side_by_side_bar
 from oplot.plot_stats import plot_confusion_matrix
+from oplot.matrix import heatmap
